==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>سىستېمىنى كەينىگە ياندۇرۇۋاتىدۇ ، ساقلاپ تۇرۇڭ ...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>قايتالمىدى</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتىش قوزغىتىش</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>يېڭىلاش ئۈزۈلۈپ قالغانلىقتىن بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>DPKG خاتالىقى تۈپەيلى بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>دىسكا سىغىمى يەتمىگەچكە بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%1 دىن بۇرۇن زاپاسلانغان %2 گە قايتىشنى جەزملەشتۈرەمسىز؟</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>بىكار قىلىش ۋە قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation> جەزملەش</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.35.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>سىستېمىنى كەينىگە ياندۇرۇۋاتىدۇ ، ساقلاپ تۇرۇڭ ...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>قايتالمىدى</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتىش قوزغىتىش</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>يېڭىلاش ئۈزۈلۈپ قالغانلىقتىن بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>DPKG خاتالىقى تۈپەيلى بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>دىسكا سىغىمى يەتمىگەچكە بۇ قېتىملىق يېڭىلاش مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>%1 دىن بۇرۇن زاپاسلانغان %2 گە قايتىشنى جەزملەشتۈرەمسىز؟</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>بىكار قىلىش ۋە قايتا قوزغىتىش</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation> جەزملەش</translation>
    </message>
</context>
</TS>
